#[non_exhaustive]pub struct CreateStreamInputBuilder { /* private fields */ }Expand description
A builder for CreateStreamInput.
Implementations
Sourceimpl CreateStreamInputBuilder
impl CreateStreamInputBuilder
Sourcepub fn cluster_identifier(self, input: impl Into<String>) -> Self
pub fn cluster_identifier(self, input: impl Into<String>) -> Self
The ID of the cluster for which to create the stream.
This field is required.Sourcepub fn set_cluster_identifier(self, input: Option<String>) -> Self
pub fn set_cluster_identifier(self, input: Option<String>) -> Self
The ID of the cluster for which to create the stream.
Sourcepub fn get_cluster_identifier(&self) -> &Option<String>
pub fn get_cluster_identifier(&self) -> &Option<String>
The ID of the cluster for which to create the stream.
Sourcepub fn target_definition(self, input: TargetDefinition) -> Self
pub fn target_definition(self, input: TargetDefinition) -> Self
The target destination configuration for the stream. Contains Kinesis stream configuration including stream ARN and IAM role ARN.
This field is required.Sourcepub fn set_target_definition(self, input: Option<TargetDefinition>) -> Self
pub fn set_target_definition(self, input: Option<TargetDefinition>) -> Self
The target destination configuration for the stream. Contains Kinesis stream configuration including stream ARN and IAM role ARN.
Sourcepub fn get_target_definition(&self) -> &Option<TargetDefinition>
pub fn get_target_definition(&self) -> &Option<TargetDefinition>
The target destination configuration for the stream. Contains Kinesis stream configuration including stream ARN and IAM role ARN.
Sourcepub fn ordering(self, input: StreamOrdering) -> Self
pub fn ordering(self, input: StreamOrdering) -> Self
The ordering mode for the stream. Determines how change events are ordered when delivered to the target.
This field is required.Sourcepub fn set_ordering(self, input: Option<StreamOrdering>) -> Self
pub fn set_ordering(self, input: Option<StreamOrdering>) -> Self
The ordering mode for the stream. Determines how change events are ordered when delivered to the target.
Sourcepub fn get_ordering(&self) -> &Option<StreamOrdering>
pub fn get_ordering(&self) -> &Option<StreamOrdering>
The ordering mode for the stream. Determines how change events are ordered when delivered to the target.
Sourcepub fn format(self, input: StreamFormat) -> Self
pub fn format(self, input: StreamFormat) -> Self
The format of the stream records.
This field is required.Sourcepub fn set_format(self, input: Option<StreamFormat>) -> Self
pub fn set_format(self, input: Option<StreamFormat>) -> Self
The format of the stream records.
Sourcepub fn get_format(&self) -> &Option<StreamFormat>
pub fn get_format(&self) -> &Option<StreamFormat>
The format of the stream records.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
A map of key and value pairs to use to tag your stream.
A map of key and value pairs to use to tag your stream.
A map of key and value pairs to use to tag your stream.
Sourcepub fn client_token(self, input: impl Into<String>) -> Self
pub fn client_token(self, input: impl Into<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect.
If you don't specify a client token, the Amazon Web Services SDK automatically generates one.
Sourcepub fn set_client_token(self, input: Option<String>) -> Self
pub fn set_client_token(self, input: Option<String>) -> Self
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect.
If you don't specify a client token, the Amazon Web Services SDK automatically generates one.
Sourcepub fn get_client_token(&self) -> &Option<String>
pub fn get_client_token(&self) -> &Option<String>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect.
If you don't specify a client token, the Amazon Web Services SDK automatically generates one.
Sourcepub fn build(self) -> Result<CreateStreamInput, BuildError>
pub fn build(self) -> Result<CreateStreamInput, BuildError>
Consumes the builder and constructs a CreateStreamInput.
Sourceimpl CreateStreamInputBuilder
impl CreateStreamInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateStreamOutput, SdkError<CreateStreamError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateStreamOutput, SdkError<CreateStreamError, HttpResponse>>
Sends a request with this input using the given client.