#[non_exhaustive]pub struct CreateStreamInput {
pub cluster_identifier: Option<String>,
pub target_definition: Option<TargetDefinition>,
pub ordering: Option<StreamOrdering>,
pub format: Option<StreamFormat>,
pub tags: Option<HashMap<String, String>>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_identifier: Option<String>The ID of the cluster for which to create the stream.
target_definition: Option<TargetDefinition>The target destination configuration for the stream. Contains Kinesis stream configuration including stream ARN and IAM role ARN.
ordering: Option<StreamOrdering>The ordering mode for the stream. Determines how change events are ordered when delivered to the target.
format: Option<StreamFormat>The format of the stream records.
A map of key and value pairs to use to tag your stream.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect.
If you don't specify a client token, the Amazon Web Services SDK automatically generates one.
Implementations
Sourceimpl CreateStreamInput
impl CreateStreamInput
Sourcepub fn cluster_identifier(&self) -> Option<&str>
pub fn cluster_identifier(&self) -> Option<&str>
The ID of the cluster for which to create the stream.
Sourcepub fn target_definition(&self) -> Option<&TargetDefinition>
pub fn target_definition(&self) -> Option<&TargetDefinition>
The target destination configuration for the stream. Contains Kinesis stream configuration including stream ARN and IAM role ARN.
Sourcepub fn ordering(&self) -> Option<&StreamOrdering>
pub fn ordering(&self) -> Option<&StreamOrdering>
The ordering mode for the stream. Determines how change events are ordered when delivered to the target.
Sourcepub fn format(&self) -> Option<&StreamFormat>
pub fn format(&self) -> Option<&StreamFormat>
The format of the stream records.
A map of key and value pairs to use to tag your stream.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Idempotency ensures that an API request completes only once. With an idempotent request, if the original request completes successfully, the subsequent retries with the same client token return the result from the original successful request and they have no additional effect.
If you don't specify a client token, the Amazon Web Services SDK automatically generates one.
Sourceimpl CreateStreamInput
impl CreateStreamInput
Sourcepub fn builder() -> CreateStreamInputBuilder
pub fn builder() -> CreateStreamInputBuilder
Creates a new builder-style object to manufacture CreateStreamInput.