#[non_exhaustive]pub struct GetStreamOutput {
pub cluster_identifier: String,
pub stream_identifier: String,
pub arn: String,
pub status: StreamStatus,
pub creation_time: DateTime,
pub ordering: StreamOrdering,
pub format: StreamFormat,
pub target_definition: Option<TargetDefinition>,
pub status_reason: Option<StatusReason>,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Expand description
The output of a retrieved stream.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster_identifier: StringThe ID of the cluster for the retrieved stream.
stream_identifier: StringThe ID of the retrieved stream.
arn: StringThe ARN of the retrieved stream.
status: StreamStatusThe current status of the retrieved stream.
creation_time: DateTimeThe time when the stream was created.
ordering: StreamOrderingThe ordering mode of the stream.
format: StreamFormatThe format of the stream records.
target_definition: Option<TargetDefinition>The target definition for the stream destination.
status_reason: Option<StatusReason>Stream status reason with error code and timestamp (if applicable).
A map of tags associated with the stream.
Implementations
Sourceimpl GetStreamOutput
impl GetStreamOutput
Sourcepub fn cluster_identifier(&self) -> &str
pub fn cluster_identifier(&self) -> &str
The ID of the cluster for the retrieved stream.
Sourcepub fn stream_identifier(&self) -> &str
pub fn stream_identifier(&self) -> &str
The ID of the retrieved stream.
Sourcepub fn status(&self) -> &StreamStatus
pub fn status(&self) -> &StreamStatus
The current status of the retrieved stream.
Sourcepub fn creation_time(&self) -> &DateTime
pub fn creation_time(&self) -> &DateTime
The time when the stream was created.
Sourcepub fn ordering(&self) -> &StreamOrdering
pub fn ordering(&self) -> &StreamOrdering
The ordering mode of the stream.
Sourcepub fn format(&self) -> &StreamFormat
pub fn format(&self) -> &StreamFormat
The format of the stream records.
Sourcepub fn target_definition(&self) -> Option<&TargetDefinition>
pub fn target_definition(&self) -> Option<&TargetDefinition>
The target definition for the stream destination.
Sourcepub fn status_reason(&self) -> Option<&StatusReason>
pub fn status_reason(&self) -> Option<&StatusReason>
Stream status reason with error code and timestamp (if applicable).
A map of tags associated with the stream.
Sourceimpl GetStreamOutput
impl GetStreamOutput
Sourcepub fn builder() -> GetStreamOutputBuilder
pub fn builder() -> GetStreamOutputBuilder
Creates a new builder-style object to manufacture GetStreamOutput.