#[non_exhaustive]pub enum TargetDefinition {
Kinesis(KinesisTargetDefinition),
#[non_exhaustive] Unknown,
}Expand description
Target definition for stream destination.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Kinesis(KinesisTargetDefinition)
Kinesis stream target configuration.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl TargetDefinition
impl TargetDefinition
Sourcepub fn as_kinesis(&self) -> Result<&KinesisTargetDefinition, &Self>
pub fn as_kinesis(&self) -> Result<&KinesisTargetDefinition, &Self>
Tries to convert the enum instance into Kinesis, extracting the inner KinesisTargetDefinition.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_kinesis(&self) -> bool
pub fn is_kinesis(&self) -> bool
Returns true if this is a Kinesis.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.